@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: pipe_dev.c,v 1.1.1.1 2000/03/28 17:19:55 maxk Exp $
+ * $Id: pipe_dev.c,v 1.1.1.1.2.1 2000/11/20 07:57:33 maxk Exp $
  */ 
 
 #include "config.h"
@@ -36,7 +36,7 @@
 /* 
  * Create pipe. Return open fd. 
  */  
-int pipe_alloc(int *fd)
+int pipe_open(int *fd)
 {
     return socketpair(AF_UNIX, SOCK_STREAM, 0, fd);
 }
