@@ -1,4 +1,3 @@
-
 /*  
     VTun - Virtual Tunnel over TCP/IP network.
 
@@ -18,9 +17,15 @@
  */
 
 /*
- * $Id: lfd_encrypt.c,v 1.2 2000/05/13 23:55:57 maxk Exp $
+ * $Id: lfd_encrypt.c,v 1.2.2.4 2000/12/24 18:57:40 maxk Exp $
  */ 
 
+/*
+   Encryption module uses software developed by the OpenSSL Project
+   for use in the OpenSSL Toolkit. (http://www.openssl.org/)       
+   Copyright (c) 1998-2000 The OpenSSL Project.  All rights reserved.
+ */
+
 /*
  * This lfd_encrypt module uses MD5 to create 128 bits encryption
  * keys and BlowFish for actual data encryption.
@@ -28,6 +33,8 @@
  * several improvements and modifications by me.  
  */
 
+#include "config.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,13 +42,15 @@
 #include <strings.h>
 #include <string.h>
 
-#include <md5.h>
-#include <blowfish.h>
-
 #include "vtun.h"
 #include "linkfd.h"
 #include "lib.h"
 
+#ifdef HAVE_SSL
+
+#include <md5.h>
+#include <blowfish.h>
+
 #define ENC_BUF_SIZE VTUN_FRAME_SIZE + 16 
 #define ENC_KEY_SIZE 16
 
@@ -50,7 +59,7 @@ char * enc_buf;
 
 int alloc_encrypt(struct vtun_host *host)
 {
-   if( !(enc_buf = malloc(ENC_BUF_SIZE)) ){
+   if( !(enc_buf = lfd_alloc(ENC_BUF_SIZE)) ){
       syslog(LOG_ERR,"Can't allocate buffer for encryptor");
       return -1;
    }
@@ -63,7 +72,7 @@ int alloc_encrypt(struct vtun_host *host)
 
 int free_encrypt()
 {
-   free(enc_buf);
+   lfd_free(enc_buf); enc_buf = NULL;
 
    return 0;
 }
@@ -114,5 +123,21 @@ struct lfd_mod lfd_encrypt = {
      decrypt_buf,
      NULL,
      free_encrypt,
-     NULL,NULL
+     NULL,
+     NULL
 };
+
+#else  /* HAVE_SSL */
+
+int no_encrypt(struct vtun_host *host)
+{
+     syslog(LOG_INFO, "Encryption is not supported");
+     return -1;
+}
+
+struct lfd_mod lfd_encrypt = {
+     "Encryptor",
+     no_encrypt, NULL, NULL, NULL, NULL, NULL, NULL, NULL
+};
+
+#endif /* HAVE_SSL */
