@@ -17,9 +17,11 @@
  */
 
 /*
- * $Id: lfd_zlib.c,v 1.1.1.2 2000/03/28 17:19:41 maxk Exp $
+ * $Id: lfd_zlib.c,v 1.1.1.2.2.4 2001/01/23 05:55:40 maxk Exp $
  */ 
 
+/* ZLIB compression module */
+
 #include "config.h"
 
 #include <stdio.h>
@@ -27,15 +29,13 @@
 #include <stdlib.h>
 #include <syslog.h>
 
-#ifdef HAVE_ZLIB
-#include <zlib.h>
-#endif
-
 #include "vtun.h"
 #include "linkfd.h"
 #include "lib.h"
 
-/* ZLIB compression module */
+#ifdef HAVE_ZLIB
+
+#include <zlib.h>
 
 static z_stream zi, zd; 
 static char *zbuf;
@@ -47,6 +47,8 @@ static int zbuf_size = VTUN_FRAME_SIZE + 200;
  */  
 int zlib_alloc(struct vtun_host *host)
 {
+     int zlevel = host->zlevel ? host->zlevel : 1;
+
      zd.zalloc = (alloc_func)0;
      zd.zfree  = (free_func)0;
      zd.opaque = (voidpf)0;
@@ -54,7 +56,7 @@ int zlib_alloc(struct vtun_host *host)
      zi.zfree  = (free_func)0;
      zi.opaque = (voidpf)0;
     
-     if( deflateInit(&zd, host->zlevel ) != Z_OK ){
+     if( deflateInit(&zd, zlevel ) != Z_OK ){
 	syslog(LOG_ERR,"Can't initialize compressor");
 	return 1;
      }	
@@ -62,12 +64,12 @@ int zlib_alloc(struct vtun_host *host)
 	syslog(LOG_ERR,"Can't initialize decompressor");
 	return 1;
      }	
-     if( !(zbuf = malloc(zbuf_size)) ){
+     if( !(zbuf = lfd_alloc(zbuf_size)) ){
 	syslog(LOG_ERR,"Can't allocate buffer for the compressor");
 	return 1;
      }
    
-     syslog(LOG_INFO,"ZLIB compression[level %d] initialized.", host->zlevel);
+     syslog(LOG_INFO,"ZLIB compression[level %d] initialized.", zlevel);
      return 0;
 }
 
@@ -80,13 +82,15 @@ int zlib_free()
 {
      deflateEnd(&zd);
      inflateEnd(&zi);
-     free(zbuf);
+
+     lfd_free(zbuf); zbuf = NULL;
+
      return 0;
 }
 
 static int expand_zbuf(z_stream *zs, int len)
 {
-     if( !(zbuf = realloc(zbuf,zbuf_size+len)) )
+     if( !(zbuf = lfd_realloc(zbuf,zbuf_size+len)) )
          return -1;
      zs->next_out = zbuf + zbuf_size;
      zs->avail_out = len;
@@ -165,5 +169,21 @@ struct lfd_mod lfd_zlib = {
      zlib_decomp,
      NULL,
      zlib_free,
-     NULL,NULL
+     NULL,
+     NULL
 };
+
+#else  /* HAVE_ZLIB */
+
+int no_zlib(struct vtun_host *host)
+{
+     syslog(LOG_INFO, "ZLIB compression is not supported");
+     return -1;
+}
+
+struct lfd_mod lfd_zlib = {
+     "ZLIB",
+     no_zlib, NULL, NULL, NULL, NULL, NULL, NULL, NULL
+};
+
+#endif /* HAVE_ZLIB */
