@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: lib.h,v 1.2 2000/04/05 02:39:54 maxk Exp $
+ * $Id: lib.h,v 1.2.2.1 2000/07/06 04:17:31 maxk Exp $
  */ 
 #ifndef _VTUN_LIB_H
 #define _VTUN_LIB_H
@@ -55,7 +55,7 @@ extern inline int read_n(int fd, char *buf, int len)
 
 	do {
 	  if( (w = read(fd, buf, len)) < 0 ){
-	     if( errno == EINTR && errno == EAGAIN )
+	     if( errno == EINTR || errno == EAGAIN )
  	        continue;
 	     return -1;
 	  }
@@ -74,7 +74,7 @@ extern inline int write_n(int fd, char *buf, int len)
 
 	do {
  	  if( (w = write(fd, buf, len)) < 0 ){
-	     if( errno == EINTR && errno == EAGAIN )
+	     if( errno == EINTR || errno == EAGAIN )
   	         continue;
 	     return -1;
 	  }
