@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: vtun.h,v 1.7 2000/05/30 20:40:02 maxk Exp $
+ * $Id: vtun.h,v 1.7.2.3 2001/01/10 01:46:29 maxk Exp $
  */ 
 #ifndef _VTUN_H
 #define _VTUN_H
@@ -89,6 +89,7 @@ struct vtun_host {
    llist down;
 
    int  flags;
+   int  timeout;
    int  spd_in;
    int  spd_out;
    int  zlevel;
@@ -99,6 +100,10 @@ struct vtun_host {
    /* Multiple connections */
    int  multi;
 
+   /* Keep Alive */
+   int ka_interval;
+   int ka_failure;
+
    /* Source address */
    struct vtun_addr src_addr;
 
@@ -130,6 +135,7 @@ extern llist host_list;
 #define VTUN_CLNT_MASK  0xf000
 
 #define VTUN_STAT	0x1000
+#define VTUN_PERSIST    0x2000
 
 /* Constants and flags for VTun protocol */
 #define VTUN_FRAME_SIZE     2048
@@ -151,8 +157,8 @@ extern llist host_list;
 
 /* Global options */
 struct vtun_opts {
-   int persist;
-   int timeout;
+   int  timeout;
+   int  persist;
 
    char *cfg_file;
 
